/*
**  File:        main.cc
**  Program:     Sensor
**  Purpose:     Modeling and simulation of a wireless sensor network
**  Version:     5.0
**  Author:      Michele Garetto / Dario Panno
**  Last Update: January 21 2003
**  Requires:    gsl library (gnu scientific library)
*/

#include <stdio.h>

#include "sensor.h"
#include "topology.h"
#include "service.h"
#include "simulation.h"
#include "message.h"
#include "queue.h"

/* definition of the Random Number Generator */
gsl_rng* RNG::rng_ = gsl_rng_alloc(gsl_rng_mt19937);	 /* MT19937 Matsumoto, Nishimura */

Message* Message::free_ = 0;	// initialize list of free messages

int main(int argc, char *argv[])
{	
	RNG::inputseed();

	Topology* topol = new Topology();
	topol->inputparameters();
	
	Simulation* sim = new Simulation(topol);
	sim->inputparameters();
	
	topol->createtopology(sim->simtype());
	topol->routing();

	sim->execute();

	return 0;
}
